#Simple calculation of reaction forces and efficiency
# for a worm and worm-gear. Currently set up for Lego worms.
# Notation matches Shigley textbook.
# Modified: 1.18.2011 -mrc; python version Jan2016

import numpy as np

#Input torque on worm (the 'worm' is not the 'worm_gear')
Tw = 0.01  #Nm input torque applied to worm
motor_rpm = 2000. #input worm speed in rpm
omegaw = motor_rpm*2*np.pi/60 #Worm speed in radians/sec

Pin = Tw*omegaw   #Input power in watts

########## Physical constants ################
mu = np.nan                        #for ABS plastic (lower if lubed)
phi = (10./180)*np.pi           #approx pressure angle, Lego
dw = 6.86e-3                    #worm dia in meters
lambdaw = np.arctan(np.pi/(dw*1000*np.pi))  #Lego worm helix angle

Ng = np.nan                         #number teeth on mating gear
Pitch = 1.0                     #Teeth per mm of diameter
dg = 0.001*(Ng/Pitch)           #Diameter in meters
#####################################################

#Get worm thread tangential force from torque,
#then get total force vector F and other components
ft = Tw/(dw/2)                 
F = ft/(np.cos(phi)*np.sin(lambdaw) + mu*np.cos(lambdaw) )
fr = F*np.sin(phi)
fa = F*(np.cos(phi)*np.cos(lambdaw) - mu*np.sin(lambdaw) )

#Compute the efficiency
effic = (np.cos(phi)-mu*np.tan(lambdaw)) / (np.cos(phi)+mu*(1./np.tan(lambdaw))) 
#Strangely, there is no np.cot() in numpy...

#Check some ratios. How big are the various
#components of F?

axial = fa/F
radial = fr/F
tangential = ft/F

#Compute forces on the mating gear using power flow
# Tg*omega_g = effic * (Tw*omega_w)
# where omega_w = Ng * omega_g
Tg = effic*Ng*Tw
#Should be same as fa*Va 

Va = (dw/2.)*omegaw*np.tan(lambdaw)


################################
#Handy constants, conversion factors
m_to_in = 39.37                     #Meters to inches
N_to_lbf = 0.2248                   #Newtons to pounds force
Nm_to_inlbf = N_to_lbf*m_to_in      #Nm to inchpounds torque
inprsec_ftprmin = 60.0/12           #inches/second to feet/minute
rpm_to_radps = 2*np.pi/60           #rotations/minute to radians/second
deg_to_rad = np.pi/180              #degrees to radians
###############################

###Input constants from Grear Stress tables#####
Qv = np.nan                  #Lego gears are high quality
Km = np.nan                  #Not quite full face contact
Ko = np.nan                  #1.25 or 1.5 also possible
Jlewis = np.nan              #A conservative estimate...
################################################


#Convert to English AGMA units
FaceWidth = 0.12         #Lego facewidth in inches
Pitch_in = Pitch*25.4    #Pitch in inches
Vtan = Va*m_to_in        #Tangential velocity inches/sec
Ftan = fa*N_to_lbf       #Tangential force, lbf
rgear = 0.5*Ng/Pitch_in

B = 0.25*(12.0-Qv)**(2.0/3.0)
if Qv > 12:
    B = 0
A = 50.0+56.0*(1.0-B)
Kv = ((A+np.sqrt(Vtan*inprsec_ftprmin))/A)**B #velocity factor
SigmaLewis = (Ftan*Pitch_in*Ko*Km*Kv)/(FaceWidth*Jlewis)

#Compare with about 8000psi for ABS plastic.

