%Simple calculation of reaction forces and efficiency
% for a worm and worm-gear. Currently set up for Lego worms.
% Notation matches Shigley textbook.
% Modified: 1.18.2011 -mrc; python version Jan2016

%Input torque on worm (the 'worm' is not the 'worm_gear')
Tw = 0.01;  %Nm input torque applied to worm
motor_rpm = 2000; %input worm speed in rpm
omegaw = motor_rpm*2*pi/60; %Worm speed in radians/sec

Pin = Tw*omegaw   %Input power

%%%%%%%%%% Physical constants %%%%%%%%%%%%%%%%
mu = nan;                        %for ABS plastic (lower if lubed)
phi = (10./180)*pi;              %approx pressure angle, Lego
dw = 6.86e-3;                    %worm dia in meters
lambdaw = atan(pi/(dw*1000*pi)); %Lego worm helix angle

Ng = nan;                         %number teeth on mating gear
Pitch = 1.0;                     %Teeth per mm of diameter
dg = 0.001*(Ng/Pitch);           %Diameter in meters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Get worm thread tangential force from torque,
%then get total force vector F and other components
ft = Tw/(dw/2);                 
F = ft/(cos(phi)*sin(lambdaw) + mu*cos(lambdaw) );
fr = F*sin(phi);
fa = F*(cos(phi)*cos(lambdaw) - mu*sin(lambdaw) );

%Compute the efficiency
effic = (cos(phi)-mu*tan(lambdaw)) / (cos(phi)+mu*(1/tan(lambdaw))); 



%Check some ratios. How big are the various
%components of F?

axial = fa/F
radial = fr/F
tangential = ft/F

%Compute forces on the mating gear using power flow
% Tg*omega_g = effic * (Tw*omega_w)
% where omega_w = Ng * omega_g
Tg = effic*Ng*Tw
%Should be same as fa*Va 
% Tg = fa*dw/2
Va = (dw/2)*omegaw*tan(lambdaw)
iszero = effic*Tw*omegaw-fa*Va



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Handy constants, conversion factors
m_to_in = 39.37;                    %Meters to inches
N_to_lbf = 0.2248;                  %Newtons to pounds force
Nm_to_inlbf = N_to_lbf*m_to_in;     %Nm to inchpounds torque
inprsec_ftprmin = 60.0/12;          %inches/second to feet/minute
rpm_to_radps = 2*pi/60;             %rotations/minute to radians/second
deg_to_rad = pi/180;                %degrees to radians
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%Input constants from Grear Stress tables%%%%%
Qv = nan;                  %Lego gears are high quality
Km = nan;                  %Not quite full face contact
Ko = nan;                 %1.25 or 1.5 also possible
Jlewis = nan;            %A conservative estimate...
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Convert to English AGMA units
FaceWidth = 0.12;         %Lego facewidth in inches
Pitch_in = Pitch*25.4;    %Pitch in inches
Vtan = Va*m_to_in;        %Tangential velocity inches/sec
Ftan = fa*N_to_lbf;       %Tangential force, lbf
rgear = 0.5*Ng/Pitch_in;

B = 0.25*(12.0-Qv)^(2.0/3.0);
if Qv > 12
    B = 0;
end
A = 50.0+56.0*(1.0-B);
Kv = ((A+sqrt(Vtan*inprsec_ftprmin))/A)^B; %velocity factor
SigmaLewis = (Ftan*Pitch_in*Ko*Km*Kv)/(FaceWidth*Jlewis)

%Compare with about 8000psi for ABS plastic.

